ggprerec plots Precision (PPV) v Recall (Sensitivity)
ggprerec(
x1,
x2 = NULL,
y = NULL,
show_smooth = TRUE,
smooth_method = "loess",
smooth_span = 0.75,
smooth_se = FALSE
)A ggplot object displaying the precision-recall curve(s) with recall (sensitivity) on the x-axis and precision (positive predictive value) on the y-axis. If two models are provided, both curves are shown for comparison.
Either a logistic regression fitted using glm (base package) or lrm (rms package) or alculated probabilities (eg through a logistic regression model) of the baseline model. Must be between 0 & 1
Either a logistic regression fitted using glm (base package) or lrm (rms package) or calculated probabilities (eg through a logistic regression model) of the new (alternative) model. Must be between 0 & 1
Binary of outcome of interest. Must be 0 or 1 (if fitted models are provided this is extracted from the fit which for an rms fit must have x = TRUE, y = TRUE).
Logical, whether to display smoothed curves (default = TRUE)
Smoothing method for geom_smooth. Options: "loess", "lm", "glm", "gam". Default is "loess"
Span parameter for loess smoothing, controls the degree of smoothing (default = 0.75). Lower values = less smooth
Logical, whether to display confidence interval around smooth (default = FALSE)